Structs
- Singly
Linked List - A singly-linked list implementation with efficient insertion at the front and back.
- Sorted
List - An ordered collection that maintains its elements in sorted order.
Traits
- List
- This trait defines common API for all list implementations.