SortedList

Struct SortedList 

pub struct SortedList<T> { /* private fields */ }
An ordered collection that maintains its elements in sorted order.

The SortedList automatically keeps elements sorted upon insertion, ensuring efficient search operations.

Type Parameters

  • T: The type of elements stored in the list. Must implement PartialOrd.

Examples

use plain_ds::SortedList;

let mut list = SortedList::new();
list.push(3);
list.push(1);
list.push(2);

assert_eq!(list.len(), 3);
assert_eq!(list.to_vec(), vec![1, 2, 3]);

Implementations

Source

impl<T> SortedList<T>

pub fn new() -> Self

Creates empty ordered list.

pub fn from_slice(slice: &[T]) -> Self
where T: Clone + PartialOrd,

Creates list from slice.

Efficiency: O(n)

pub fn to_vec(&self) -> Vec<T>
where T: Clone,

Collect list values into a vector.

Efficiency: O(n)