FileTree

Struct FileTree 

pub struct FileTree { /* private fields */ }
FileTree is a specialized data structure for compactly storing in memory hierarchical structure of files and directories. It also provides fast search and access to data.

Implementation Features
If all the file paths you plan to store in FileTree begin with the same long prefix, it’s better to store this prefix separately, outside of this structure.

For example, you have several file paths:

 /very/long/prefix/to/my/files/file.01

 /very/long/prefix/to/my/files/alfa/file.02

 /very/long/prefix/to/my/files/beta/gamma/file.03

Common prefix is: /very/long/prefix/to/my/files - store it separately.

And in FileTree store short paths: /file.01, /alfa/file.02 and /beta/gamma/file.03.

In this case, FileTree will store the following hierarchy:

                      /
        +-------------+--------------+
     file.01         alfa           beta
                      /              /
                   file.02         gamma
                                     /
                                  file.03

All paths in FileTree must be absolute (i.e., start with /).
Do not include any prefixes into paths (for example, like in Windows - C:).

Implementations

Source

impl FileTree

pub fn new() -> Self

Creates new file-tree and initialize root as /.

pub fn is_empty(&self) -> bool

Checks if the tree is empty.

Efficiency: O(1)

pub fn contains_file<P: AsRef<Path>>(&self, path: P) -> Result<bool>

Checks if path is contained in the tree as file.

Efficiency: O(n), where n is a path length (in components).

pub fn contains_dir<P: AsRef<Path>>(&self, path: P) -> Result<bool>

Checks if path is contained in the tree as directory.

Efficiency: O(n), where n is a path length (in components).

pub fn add_dir<P: AsRef<Path>>(&mut self, path: P) -> Result<()>

Add directory into tree.

path must be absolute (i.e., start with /) and not contain prefixes (for example, like in Windows - C:).

Efficiency: O(n), where n is a path length (in components).

pub fn add_file<P: AsRef<Path>>(&mut self, path: P) -> Result<()>

Add file into tree.

path must be absolute (i.e., start with /) and not contain prefixes (for example, like in Windows - C:).

Efficiency: O(n), where n is a path length (in components).

pub fn remove_file<P: AsRef<Path>>(&mut self, path: P) -> Result<()>

Removes a file from the tree.

pub fn remove_dir<P: AsRef<Path>>(&mut self, path: P) -> Result<()>

Removes a directory (with all its entries) from the tree.

pub fn clear(&mut self)

Clears all tree contents.

Efficiency: O(1)

pub fn visit(&self, visitor: impl FnMut(&Path))

Visits all leaf elements in the tree and performs a visitor for each of them.